@@ -22,9 +22,14 @@
 /* Define if we have STREAMS */
 #undef STREAMSPTY
 
+/* Define if we have TERMCAP */
+#undef TERMCAP
+
 /* Define if socks should be used */
 #undef USE_SOCKS
 
 /* Define if ssl should be used */
 #undef USE_SSL
 
+/* Define if we have TERMIO */
+#undef USE_TERMIO
