@@ -35,6 +35,12 @@
 static char sccsid[] = "@(#)commands.c	8.2 (Berkeley) 12/15/93";
 #endif /* not lint */
 
+/* 	$Id: commands.c,v 1.3 1995/08/25 13:19:25 martin Exp $	 */
+
+#ifndef lint
+static char vcid[] = "$Id: commands.c,v 1.3 1995/08/25 13:19:25 martin Exp $";
+#endif /* lint */
+
 #include "../config.h"
 
 #if	defined(unix)
@@ -867,7 +873,7 @@ toggle(argc, argv)
  */
 
 #ifdef	USE_TERMIO
-struct termio new_tc = { 0 };
+struct termios new_tc = { 0 };
 #endif
 
 struct setlist {
