@@ -40,6 +40,12 @@ static char sccsid[] = "@(#)sys_bsd.c	8.2 (Berkeley) 12/15/93";
  * (at least between 4.x and dos) which is used in telnet.c.
  */
 
+/* 	$Id: sys_bsd.c,v 1.3 1995/08/25 13:22:37 martin Exp $	 */
+
+#ifndef lint
+static char vcid[] = "$Id: sys_bsd.c,v 1.3 1995/08/25 13:22:37 martin Exp $";
+#endif /* lint */
+
 #include "../config.h"
 
 #include <fcntl.h>
@@ -54,6 +60,9 @@ static char sccsid[] = "@(#)sys_bsd.c	8.2 (Berkeley) 12/15/93";
 #  include <time.h>
 # endif
 #endif
+#if defined(HAVE_SYS_SELECT_H) && !defined(SCO)
+# include <sys/select.h>
+#endif
 #include <sys/socket.h>
 #include <signal.h>
 #include <errno.h>
@@ -92,8 +101,8 @@ int	olmode = 0;
 # define old_tc ottyb
 
 #else	/* USE_TERMIO */
-struct	termio old_tc = { 0 };
-extern struct termio new_tc;
+struct	termios old_tc = { 0 };
+extern struct termios new_tc;
 
 # ifndef	TCSANOW
 #  ifdef TCSETS
@@ -404,7 +413,7 @@ TerminalNewMode(f)
     struct sgttyb sb;
     int lmode;
 #else	/* USE_TERMIO */
-    struct termio tmp_tc;
+    struct termios tmp_tc;
 #endif	/* USE_TERMIO */
     int onoff;
     int old;
