@@ -35,6 +35,12 @@
 static char sccsid[] = "@(#)utilities.c	8.2 (Berkeley) 12/15/93";
 #endif /* not lint */
 
+/* 	$Id: utilities.c,v 1.3 1995/08/25 13:24:22 martin Exp $	 */
+
+#ifndef lint
+static char vcid[] = "$Id: utilities.c,v 1.3 1995/08/25 13:24:22 martin Exp $";
+#endif /* lint */
+
 #include "../config.h"
 
 #define	TELOPTS
@@ -52,6 +58,9 @@ static char sccsid[] = "@(#)utilities.c	8.2 (Berkeley) 12/15/93";
 #  include <time.h>
 # endif
 #endif
+#if defined(HAVE_SYS_SELECT_H) && !defined(SCO)
+# include <sys/select.h>
+#endif
 
 #include <ctype.h>
 
