@@ -35,6 +35,12 @@
 static char sccsid[] = "@(#)sys_term.c	8.2 (Berkeley) 12/15/93";
 #endif /* not lint */
 
+/* 	$Id: sys_term.c,v 1.3 1995/08/25 13:28:23 martin Exp $	 */
+
+#ifndef lint
+static char vcid[] = "$Id: sys_term.c,v 1.3 1995/08/25 13:28:23 martin Exp $";
+#endif /* lint */
+
 #include "telnetd.h"
 #include "pathnames.h"
 
@@ -42,7 +48,7 @@ static char sccsid[] = "@(#)sys_term.c	8.2 (Berkeley) 12/15/93";
 #include <libtelnet/auth.h>
 #endif
 
-#if defined(CRAY) || defined(__hpux) || defined(SCO)
+#if defined(CRAY) || defined(__hpux) || defined(SCO) || defined(_AIX)
 # define PARENT_DOES_UTMP
 #endif
 
@@ -95,12 +101,11 @@ extern struct sysv sysv;
 # ifdef HAVE_SAC_H
 #  include <sac.h>
 # endif
-#include <sac.h>
-#include <sys/stropts.h>
+# include <sys/stropts.h>
 # ifdef HAVE_SYS_STRTTY_H
 #  include <sys/strtty.h>
 # endif
-#include <sys/tty.h>
+# include <sys/tty.h>
 # ifdef HAVE_SYS_PTYVAR_H
 #  include <sys/ptyvar.h>
 # endif
@@ -116,7 +121,9 @@ extern struct sysv sysv;
 #include <sys/resource.h>
 #include <sys/proc.h>
 #endif
-#include <sys/tty.h>
+#ifdef HAVE_SYS_TTY_H
+# include <sys/tty.h>
+#endif
 #ifdef	t_erase
 #undef	t_erase
 #undef	t_kill
@@ -137,6 +144,12 @@ extern struct sysv sysv;
 #if defined(UNICOS5) && defined(CRAY2) && !defined(EXTPROC)
 # define EXTPROC 0400
 #endif
+#if defined(_AIX)
+# define EXTPROC 0400
+#endif
+#if defined(linux)
+# define EXTPROC 0400
+#endif
 
 #ifdef __hpux
 #undef TIOCSCTTY
@@ -1899,7 +1912,7 @@ utmp_sig_reset()
 	(void) signal(SIGUSR1, func);	/* reset handler to default */
 }
 
-#if defined(__hpux) || defined(SCO)
+#if defined(__hpux) || defined(SCO) || defined(_AIX)
 # define sigoff() /* do nothing */
 # define sigon() /* do nothing */
 #endif
